import { Component, OnInit } from "@angular/core";
import { MainService } from 'src/app/services/main.service';
import { ToolService } from 'src/app/services/tool.service';
import { NzMessageService } from 'ng-zorro-antd';
import { Subject } from 'rxjs';
import { debounceTime } from 'rxjs/operators';

@Component({
  selector: "app-big-transfusion-set",
  templateUrl: "./big-transfusion-set.component.html",
  styleUrls: ["./big-transfusion-set.component.less"],
})
export class BigTransfusionSetComponent implements OnInit {
  loading:boolean = false; //页面加载的loading
  btnLoading:boolean = false; //提交按钮的loading
  tabModalName:string = 'characteristics'; //当前选中的tab
  surgeryField = null; //手术关联业务
  hosId = this.tool.getCurrentHospital().id; //当前院区
  // 接手术关联任务类型
  infusionSolutionsTypeId:Number;
  taskTypes1:any[] = [];
  taskTypeData:{id:''};
  // 苏醒室科室
  recoveryDeptId:any;
  recoveryDepts:any[] = [];
  // 自动建单
  autoCreateOrders:any[] = [
    {label:'是否开启',value: 0}
  ];
  // 是否开通送回病房
  autoSendWard:any[] = [
    {label:'是否开启',value: 0}
  ];
  // 是否开通送回苏醒室
  autoSendAwakeningRoom:any[] = [
    {label:'是否开启',value: 0}
  ];
  // 是否开通关联手术清洁建单
  autoRemandClean:any[] = [
    {label:'是否开启',value: 0}
  ];
  // 是否开启手术即将开始通知
  surgeryBegin:any[] = [
    {label:'是否开启',value: 0}
  ];
  // 建单时间
  autoTime:Date | null = null;
  tasktype1Id:any;
  tasktype2Id:any;
  cleanTypeId:any;
	associationTypeIds:any;
	questionnaireManagementData:any; //调查问卷数据
	questionnaireIds:Number; //问卷参数
	intervalTime:string = ''; //间隔时间参数
	taskTypeIds:any = []; //任务类型参数
	editId:'';
	targetData:any = [];
	stateData:any = [];
	// 间隔时间数据
	timeData:any[] = [
	  {label:'10',value: 10},
		{label:'15',value: 15},
		{label:'30',value: 30},
		{label:'60',value: 60}
	];
  // 配置
  configs:any = {};
  searchTimerSubject = new Subject();
  constructor(private mainService: MainService,private tool: ToolService,private msg: NzMessageService) {}

  ngOnInit():void {
    // todo
    this.searchTimerSubject.pipe(debounceTime(500)).subscribe((v) => {
      let fun = v[0];
      fun.call(this, v[1], v[2], v[3]);
    });
    this.getTaskTypes('', true);
  }

  // 切换tab
  tabModal(tabModalName:string){
    this.tabModalName = tabModalName;
  }

  // 保存
  submitForm() {
    if(!this.infusionSolutionsTypeId){
      this.msg.create("warning", "请选择任务类型！");
      return;
    }
    let editData = {
			id:'',
			taskType:this.taskTypeData.id,
			hosId: this.hosId,
			infusionSolutionsTypeId:this.infusionSolutionsTypeId, //任务类型参数
			autoCreate:0
    };
		if(this.editId){
			editData.id = this.editId
		}else{
			delete editData.id 
		}
		if(this.autoCreateOrders[0].checked){
			editData.autoCreate = 1
		}else{
			delete editData.autoCreate
		}
    this.btnLoading = true;
    this.mainService
      .simplePost("addData", "taskTypeConfig", editData)
      .subscribe((result) => {
        this.btnLoading = false;
        if (result.status == 200) {
          this.getConfig();
        }
      });
  }
	
  // 用户输入搜索任务类型
  isLoading: boolean = false;
  changeTasktype(e) {
    this.searchTimer(this.getTaskTypes, e, false);
  }

  // 边输入边搜索节流阀
  searchTimer(fun, e, isFirst, type?) {
    this.isLoading = true;
    this.searchTimerSubject.next([fun, e, isFirst, type]);
  }
	
  //获取关联任务类型
  // 1 患者其他服务
  // 2 其他临床服务
  getTaskTypes(e:string = '', isFirst:boolean = false) {
    isFirst && (this.loading = true);
    let postData:any = {
      idx: 0,
      sum: 9999,
      taskType: {
        taskName: e,
        simpleQuery: true,
				associationType : {
					key: 'association_types',
					value: 'other'
				},
        hosId: {
          id: this.hosId
        }
      }
    };
    this.isLoading = true;
    this.mainService
      .getFetchDataList("simple/data", "taskType", postData)
      .subscribe((result) => {
        this.isLoading = false;
        if (result.status == 200) {
          this.taskTypes1 = result.list || [];
					this.getTaskTypesId();
        }
      });
  }
	
	// 获取任务id
	getTaskTypesId() {
		this.mainService.getDictionary("list", "ordinary_field").subscribe((data) => {
			this.taskTypeData = data.find(i=>i.value=='infusionSolutions')
			this.getConfig();
		});
	}
	
  // 获取配置
  getConfig() {
    this.loading = true;
    let postData = {
      idx: 0,
      sum: 10,
      taskTypeConfig: {
				hosId:this.hosId,
				taskType:this.taskTypeData.id
      }
    };
    this.mainService
      .getFetchDataList("simple/data", "taskTypeConfig", postData)
      .subscribe((result) => {
        this.loading = false;
        if (result.status == 200) {
    			let data = result.list[0] || {};
					this.editId = data.id
					this.autoCreateOrders[0].checked = data.autoCreate == 1;
    			this.infusionSolutionsTypeId = data.infusionSolutionsTypeId
        }
      });
  }
}

